@@ -5,17 +5,17 @@
 modname = 'cubicweb_celerytask'
 distname = 'cubicweb-celerytask'
 
-numversion = (0, 7, 2)
+numversion = (0, 7, 3)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 description = 'Run and monitor celery tasks'
-web = 'http://www.cubicweb.org/project/%s' % distname
+web = 'https://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.19',
+    'cubicweb': '>= 3.26.18',
     'six': '>= 1.4.0',
     'celery': '>=4,<5',
     'cw-celerytask-helpers': '>= 0.7.0, < 0.8.0',
@@ -26,5 +26,7 @@ classifiers = [
     'Environment :: Web Environment',
     'Framework :: CubicWeb',
     'Programming Language :: Python',
+    'Programming Language :: Python :: 2',
+    'Programming Language :: Python :: 3',
     'Programming Language :: JavaScript',
 ]
