@@ -13,7 +13,7 @@
 # details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 
 """cubicweb-celerytask entity's classes"""
 import six
@@ -204,16 +204,18 @@ class ICeleryTask(EntityAdapter):
         if celery.current_app.conf.task_always_eager:
             return 1.
         result = self.result
-        if result.info and 'progress' in result.info:
-            return result.info['progress']
-        elif self.entity.reverse_parent_task:
+        try:
+            if result.info and 'progress' in result.info:
+                return result.info['progress']
+        except TypeError:
+            pass
+        if self.entity.reverse_parent_task:
             children = self.entity.reverse_parent_task
             return sum(child.cw_adapt_to('ICeleryTask').progress
                        for child in children) / len(children)
-        elif result.state == STATES.SUCCESS:
+        if result.state == STATES.SUCCESS:
             return 1.
-        else:
-            return 0.
+        return 0.
 
     @property
     def state(self):
